@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# $Id: addbiblio.pl,v 1.52.2.57 2006/10/13 08:33:34 tipaul Exp $
+# $Id: addbiblio.pl,v 1.52.2.58 2006/11/03 10:56:59 hdl Exp $
 
 # Copyright 2000-2002 Katipo Communications
 #
@@ -94,7 +94,7 @@ sub MARCfindbreeding {
 	$sth->execute($id);
 	my ($file,$marc,$encoding) = $sth->fetchrow;
 	if ($marc) {
-		my $record = MARC::File::USMARC::decode($marc);
+		my $record = fixEncoding($marc);
 		if (ref($record) eq undef) {
 			return -1;
 		} else {
