@@ -34,6 +34,9 @@ $template->param(suggestions_loop => $order_loop,
 				author => $author,
 				name => $name,
 				from_placed_on =>$from_placed_on,
-				to_placed_on =>$to_placed_on
+				to_placed_on =>$to_placed_on,
+				intranetcolorstylesheet => C4::Context->preference("intranetcolorstylesheet"),
+		intranetstylesheet => C4::Context->preference("intranetstylesheet"),
+		IntranetNav => C4::Context->preference("IntranetNav"),
 );
 output_html_with_http_headers $input, $cookie, $template->output;
