@@ -27,5 +27,8 @@ $template->param(
 	subscriptions => \@subscriptions,
 	title => $title,
 	ISSN => $ISSN,
+	intranetcolorstylesheet => C4::Context->preference("intranetcolorstylesheet"),
+		intranetstylesheet => C4::Context->preference("intranetstylesheet"),
+		IntranetNav => C4::Context->preference("IntranetNav"),
 	);
 output_html_with_http_headers $query, $cookie, $template->output;
