@@ -40,6 +40,11 @@ sub gethelptemplate {
 	$template->param(themelang => '/intranet-tmpl' . "/$theme/$lang",
 							interface => '/intranet-tmpl',
 							theme => $theme,
-							lang => $lang);
+							lang => $lang,
+							TemplateEncoding => C4::Context->preference("TemplateEncoding")."",
+							intranetcolorstylesheet => C4::Context->preference("intranetcolorstylesheet"),
+		intranetstylesheet => C4::Context->preference("intranetstylesheet"),
+		IntranetNav => C4::Context->preference("IntranetNav"),
+			);
 	return $template;
 }
