@@ -3,7 +3,7 @@
 
 package C4::Circulation::Circ2;
 
-# $Id: Circ2.pm,v 1.87.2.11 2005/09/23 09:31:15 tipaul Exp $
+# $Id: Circ2.pm,v 1.87.2.16 2006/09/14 14:31:33 oleonard Exp $
 
 #package to deal with Returns
 #written 3/11/99 by olwen@katipo.co.nz
@@ -34,6 +34,7 @@ use C4::Context;
 use C4::Stats;
 use C4::Reserves2;
 use C4::Koha;
+use C4::Biblio;
 use C4::Accounts;
 use Date::Manip;
 
@@ -235,6 +236,12 @@ sub getpatroninformation {
 	$sth->finish;
 	$borrower->{'flags'}=$flags;
 	$borrower->{'authflags'} = $accessflagshash;
+
+	# find out how long the membership lasts
+	my $sth=$dbh->prepare("select enrolmentperiod from categories where categorycode = ?");
+	$sth->execute($borrower->{'categorycode'});
+	my $enrolment = $sth->fetchrow;
+	$borrower->{'enrolmentperiod'} = $enrolment;
 	return ($borrower); #, $flags, $accessflagshash);
 }
 
@@ -476,6 +483,14 @@ sub transferbook {
 	#actually do the transfer....
 	if ($dotransfer) {
 		dotransfer($iteminformation->{'itemnumber'}, $fbr, $tbr);
+		my $dbh= C4::Context->dbh;
+		my ($tagfield,$tagsubfield) = MARCfind_marc_from_kohafield($dbh,"items.holdingbranch");
+		my $bibid = MARCfind_MARCbibid_from_oldbiblionumber( $dbh, $iteminformation->{'biblionumber'} );
+		my $marcitem = MARCgetitem($dbh, $bibid, $iteminformation->{'itemnumber'});
+		if ($marcitem->field($tagfield)){
+			$marcitem->field($tagfield)->update($tagsubfield=> $tbr);
+			MARCmoditem($dbh,$marcitem,$bibid,$iteminformation->{'itemnumber'});
+		}
 		$messages->{'WasTransfered'} = 1;
 	}
 	return ($dotransfer, $messages, $iteminformation);
@@ -651,7 +666,7 @@ sub TooMany ($$){
 
 	$sth->execute("*", $type, "");
 	my $result = $sth->fetchrow_hashref;
-	if (defined($result) && $result->{maxissueqty}>=0) {
+	if (defined($result) && $result->{maxissueqty} ge 0) {
 		$sth2->execute($borrower->{'borrowernumber'}, "%$type%");
 		my $alreadyissued = $sth2->fetchrow;
 		return ("f $alreadyissued / ".($result->{maxissueqty}+0)) if ($result->{'maxissueqty'} <= $alreadyissued);
@@ -710,7 +725,7 @@ sub canbookbeissued {
 # DEBTS
 	my $amount = checkaccount($env,$borrower->{'borrowernumber'}, $dbh,$duedate);
 	if ($amount >0) {
-		$needsconfirmation{DEBT} = $amount;
+		$needsconfirmation{DEBT} = sprintf("%.2f",$amount);
 	}
 
 
@@ -738,6 +753,13 @@ sub canbookbeissued {
 	if ($iteminformation->{'restricted'} == 1) {
 		$issuingimpossible{RESTRICTED} = 1;
 	}
+	if (C4::Context->preference("IndependantBranches")){
+		my $userenv = C4::Context->userenv;
+		if (($userenv)&&($userenv->{flags} != 1)){
+			$issuingimpossible{NOTSAMEBRANCH} = 1 if ($iteminformation->{'holdingbranch'} ne $userenv->{branch} ) ;
+		}
+	}
+
 
 
 
